@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -226,9 +226,9 @@ class TranslationServiceAsyncClient:
 
             from google.cloud import translate_v3
 
-            def sample_translate_text():
+            async def sample_translate_text():
                 # Create a client
-                client = translate_v3.TranslationServiceClient()
+                client = translate_v3.TranslationServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = translate_v3.TranslateTextRequest(
@@ -238,7 +238,7 @@ class TranslationServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.translate_text(request=request)
+                response = await client.translate_text(request=request)
 
                 # Handle the response
                 print(response)
@@ -392,7 +392,12 @@ class TranslationServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -415,9 +420,9 @@ class TranslationServiceAsyncClient:
 
             from google.cloud import translate_v3
 
-            def sample_detect_language():
+            async def sample_detect_language():
                 # Create a client
-                client = translate_v3.TranslationServiceClient()
+                client = translate_v3.TranslationServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = translate_v3.DetectLanguageRequest(
@@ -426,7 +431,7 @@ class TranslationServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.detect_language(request=request)
+                response = await client.detect_language(request=request)
 
                 # Handle the response
                 print(response)
@@ -535,7 +540,12 @@ class TranslationServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -554,14 +564,13 @@ class TranslationServiceAsyncClient:
         r"""Returns a list of supported languages for
         translation.
 
-
         .. code-block:: python
 
             from google.cloud import translate_v3
 
-            def sample_get_supported_languages():
+            async def sample_get_supported_languages():
                 # Create a client
-                client = translate_v3.TranslationServiceClient()
+                client = translate_v3.TranslationServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = translate_v3.GetSupportedLanguagesRequest(
@@ -569,7 +578,7 @@ class TranslationServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_supported_languages(request=request)
+                response = await client.get_supported_languages(request=request)
 
                 # Handle the response
                 print(response)
@@ -684,7 +693,12 @@ class TranslationServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -703,9 +717,9 @@ class TranslationServiceAsyncClient:
 
             from google.cloud import translate_v3
 
-            def sample_translate_document():
+            async def sample_translate_document():
                 # Create a client
-                client = translate_v3.TranslationServiceClient()
+                client = translate_v3.TranslationServiceAsyncClient()
 
                 # Initialize request argument(s)
                 document_input_config = translate_v3.DocumentInputConfig()
@@ -718,7 +732,7 @@ class TranslationServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.translate_document(request=request)
+                response = await client.translate_document(request=request)
 
                 # Handle the response
                 print(response)
@@ -756,7 +770,12 @@ class TranslationServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -779,14 +798,13 @@ class TranslationServiceAsyncClient:
         use google.longrunning.Operation.name to poll the status
         of the call.
 
-
         .. code-block:: python
 
             from google.cloud import translate_v3
 
-            def sample_batch_translate_text():
+            async def sample_batch_translate_text():
                 # Create a client
-                client = translate_v3.TranslationServiceClient()
+                client = translate_v3.TranslationServiceAsyncClient()
 
                 # Initialize request argument(s)
                 input_configs = translate_v3.InputConfig()
@@ -808,7 +826,7 @@ class TranslationServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -850,7 +868,12 @@ class TranslationServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -886,14 +909,13 @@ class TranslationServiceAsyncClient:
         google.longrunning.Operation.name to poll the status of
         the call.
 
-
         .. code-block:: python
 
             from google.cloud import translate_v3
 
-            def sample_batch_translate_document():
+            async def sample_batch_translate_document():
                 # Create a client
-                client = translate_v3.TranslationServiceClient()
+                client = translate_v3.TranslationServiceAsyncClient()
 
                 # Initialize request argument(s)
                 input_configs = translate_v3.BatchDocumentInputConfig()
@@ -915,7 +937,7 @@ class TranslationServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1044,7 +1066,12 @@ class TranslationServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1070,14 +1097,13 @@ class TranslationServiceAsyncClient:
         r"""Creates a glossary and returns the long-running operation.
         Returns NOT_FOUND, if the project doesn't exist.
 
-
         .. code-block:: python
 
             from google.cloud import translate_v3
 
-            def sample_create_glossary():
+            async def sample_create_glossary():
                 # Create a client
-                client = translate_v3.TranslationServiceClient()
+                client = translate_v3.TranslationServiceAsyncClient()
 
                 # Initialize request argument(s)
                 glossary = translate_v3.Glossary()
@@ -1093,7 +1119,7 @@ class TranslationServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1160,7 +1186,12 @@ class TranslationServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1185,14 +1216,13 @@ class TranslationServiceAsyncClient:
         r"""Lists glossaries in a project. Returns NOT_FOUND, if the project
         doesn't exist.
 
-
         .. code-block:: python
 
             from google.cloud import translate_v3
 
-            def sample_list_glossaries():
+            async def sample_list_glossaries():
                 # Create a client
-                client = translate_v3.TranslationServiceClient()
+                client = translate_v3.TranslationServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = translate_v3.ListGlossariesRequest(
@@ -1203,7 +1233,7 @@ class TranslationServiceAsyncClient:
                 page_result = client.list_glossaries(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1273,12 +1303,20 @@ class TranslationServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListGlossariesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1296,14 +1334,13 @@ class TranslationServiceAsyncClient:
         r"""Gets a glossary. Returns NOT_FOUND, if the glossary doesn't
         exist.
 
-
         .. code-block:: python
 
             from google.cloud import translate_v3
 
-            def sample_get_glossary():
+            async def sample_get_glossary():
                 # Create a client
-                client = translate_v3.TranslationServiceClient()
+                client = translate_v3.TranslationServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = translate_v3.GetGlossaryRequest(
@@ -1311,7 +1348,7 @@ class TranslationServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_glossary(request=request)
+                response = await client.get_glossary(request=request)
 
                 # Handle the response
                 print(response)
@@ -1380,7 +1417,12 @@ class TranslationServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1398,14 +1440,13 @@ class TranslationServiceAsyncClient:
         glossary isn't created yet. Returns NOT_FOUND, if the glossary
         doesn't exist.
 
-
         .. code-block:: python
 
             from google.cloud import translate_v3
 
-            def sample_delete_glossary():
+            async def sample_delete_glossary():
                 # Create a client
-                client = translate_v3.TranslationServiceClient()
+                client = translate_v3.TranslationServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = translate_v3.DeleteGlossaryRequest(
@@ -1417,7 +1458,7 @@ class TranslationServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1489,7 +1530,12 @@ class TranslationServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1511,7 +1557,9 @@ class TranslationServiceAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-translate",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-translate",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
